@@ -50,6 +50,12 @@ describe Ethon::Easy::Informations do
     end
   end
 
+  describe "#redirect_time" do
+    it "returns float" do
+      expect(easy.redirect_time).to be_a(Float)
+    end
+  end
+
   describe "#effective_url" do
     it "returns url" do
       expect(easy.effective_url).to match(/^http:\/\/localhost:3001\/?/)
@@ -74,9 +80,18 @@ describe Ethon::Easy::Informations do
     end
   end
 
-  describe "#supports_zlib?" do
-    it "returns true" do
-      expect(easy.supports_zlib?).to be_true
+  describe "#request_size" do
+    it "returns 53" do
+      expect(easy.request_size).to eq(53)
     end
   end
+
+  describe "#supports_zlib?" do
+    it "returns true" do
+      Kernel.should_receive(:warn) #deprecation warning
+      expect(easy.supports_zlib?).to be_truthy
+    end
+  end
+
+
 end
