@@ -8,7 +8,7 @@ describe Ethon::Easy::Mirror do
     [
       :return_code, :response_code, :response_body, :response_headers,
       :total_time, :starttransfer_time, :appconnect_time,
-      :pretransfer_time, :connect_time, :namelookup_time,
+      :pretransfer_time, :connect_time, :namelookup_time, :redirect_time,
       :effective_url, :primary_ip, :redirect_count, :debug_info
     ].each do |name|
       it "contains #{name}" do
@@ -32,6 +32,12 @@ describe Ethon::Easy::Mirror do
       expect(mirror.log_informations).to be_a(Hash)
     end
 
+    it "only calls methods that exist" do
+      described_class.informations_to_log.each do |method_name|
+        expect(mirror.respond_to? method_name).to eql(true)
+      end
+    end
+
     it "includes return code" do
       expect(mirror.log_informations).to include(options)
     end
