@@ -20,10 +20,8 @@ describe Ethon::Easy::Options do
       end
 
       it "sets option" do
-        Ethon::Easy.any_instance.should_receive(:set_callbacks)
-        Ethon::Curl.should_receive(:set_option).with do |option, _, _|
-          expect(option).to be(name)
-        end
+        expect_any_instance_of(Ethon::Easy).to receive(:set_callbacks)
+        expect(Ethon::Curl).to receive(:set_option).with(name, anything, anything)
         value = case name
         when :http_version
           :httpv1_0
@@ -106,9 +104,9 @@ describe Ethon::Easy::Options do
       end
     end
 
-    if Ethon::Curl.version.match("c-ares")
+    if Ethon::Easy.supports_timeout_ms?
       context "when timeout_ms" do
-        let(:timeout_ms) { 900 }
+        let(:timeout_ms) { 100 }
 
         context "when request takes longer" do
           let(:url) { "localhost:3001?delay=1" }
@@ -120,13 +118,14 @@ describe Ethon::Easy::Options do
       end
 
       context "when connecttimeout_ms" do
-        let(:connecttimeout_ms) { 1 }
+        let(:connecttimeout_ms) { 100 }
 
         context "when cannot connect" do
           let(:url) { "localhost:3002" }
 
           it "times out" do
-            expect(easy.return_code).to eq(:couldnt_connect)
+            # this can either lead to a timeout or couldnt connect depending on which happens first
+            expect([:couldnt_connect, :operation_timedout]).to include(easy.return_code)
           end
         end
       end
